@@ -6,6 +6,8 @@
 #define CLAD_DIFFERENTIATOR_KOKKOSBUILTINS_H
 
 #include <Kokkos_Core.hpp>
+#include <cstddef>
+#include <string>
 #include <type_traits>
 #include "clad/Differentiator/Differentiator.h"
 
@@ -15,53 +17,46 @@ namespace class_functions {
 template <class DataType, class... ViewParams>
 clad::ValueAndPushforward<Kokkos::View<DataType, ViewParams...>,
                           Kokkos::View<DataType, ViewParams...>>
-constructor_pushforward(
-    clad::ConstructorPushforwardTag<Kokkos::View<DataType, ViewParams...>>,
-    const ::std::string& name, const size_t& idx0, const size_t& idx1,
-    const size_t& idx2, const size_t& idx3, const size_t& idx4,
-    const size_t& idx5, const size_t& idx6, const size_t& idx7,
-    const ::std::string& /*d_name*/, const size_t& /*d_idx0*/,
-    const size_t& /*d_idx1*/, const size_t& /*d_idx2*/,
-    const size_t& /*d_idx3*/, const size_t& /*d_idx4*/,
-    const size_t& /*d_idx5*/, const size_t& /*d_idx6*/,
-    const size_t& /*d_idx7*/) {
+constructor_pushforward(clad::Tag<Kokkos::View<DataType, ViewParams...>>,
+                        const ::std::string& name, const size_t& idx0,
+                        const size_t& idx1, const size_t& idx2,
+                        const size_t& idx3, const size_t& idx4,
+                        const size_t& idx5, const size_t& idx6,
+                        const size_t& idx7, const ::std::string& /*d_name*/,
+                        const size_t& /*d_idx0*/, const size_t& /*d_idx1*/,
+                        const size_t& /*d_idx2*/, const size_t& /*d_idx3*/,
+                        const size_t& /*d_idx4*/, const size_t& /*d_idx5*/,
+                        const size_t& /*d_idx6*/, const size_t& /*d_idx7*/) {
   return {Kokkos::View<DataType, ViewParams...>(name, idx0, idx1, idx2, idx3,
                                                 idx4, idx5, idx6, idx7),
           Kokkos::View<DataType, ViewParams...>(
               "_diff_" + name, idx0, idx1, idx2, idx3, idx4, idx5, idx6, idx7)};
 }
-template <class DataType, class... ViewParams>
+template <class DataType, size_t N, class... ViewParams>
 clad::ValueAndAdjoint<::Kokkos::View<DataType, ViewParams...>,
                       ::Kokkos::View<DataType, ViewParams...>>
 constructor_reverse_forw(
-    clad::ConstructorReverseForwTag<::Kokkos::View<DataType, ViewParams...>>,
-    const ::std::string& name, const size_t& idx0, const size_t& idx1,
-    const size_t& idx2, const size_t& idx3, const size_t& idx4,
-    const size_t& idx5, const size_t& idx6, const size_t& idx7,
-    const ::std::string& /*d_name*/, const size_t& /*d_idx0*/,
-    const size_t& /*d_idx1*/, const size_t& /*d_idx2*/,
-    const size_t& /*d_idx3*/, const size_t& /*d_idx4*/,
-    const size_t& /*d_idx5*/, const size_t& /*d_idx6*/,
-    const size_t& /*d_idx7*/) {
+    clad::Tag<::Kokkos::View<DataType, ViewParams...>>, const char (&name)[N],
+    const size_t idx0, const size_t idx1, const size_t idx2, const size_t idx3,
+    const size_t idx4, const size_t idx5, const size_t idx6, const size_t idx7,
+    const char (&d_name)[N], const size_t /*d_idx0*/, const size_t /*d_idx1*/,
+    const size_t /*d_idx2*/, const size_t /*d_idx3*/, const size_t /*d_idx4*/,
+    const size_t /*d_idx5*/, const size_t /*d_idx6*/, const size_t /*d_idx7*/) {
   return {::Kokkos::View<DataType, ViewParams...>(name, idx0, idx1, idx2, idx3,
                                                   idx4, idx5, idx6, idx7),
           ::Kokkos::View<DataType, ViewParams...>(
-              "_diff_" + name, idx0, idx1, idx2, idx3, idx4, idx5, idx6, idx7)};
+              ::std::string("_diff_") + name, idx0, idx1, idx2, idx3, idx4,
+              idx5, idx6, idx7)};
 }
-template <class DataType, class... ViewParams>
-void constructor_pullback(::Kokkos::View<DataType, ViewParams...>* v,
-                          const ::std::string& name, const size_t& idx0,
-                          const size_t& idx1, const size_t& idx2,
-                          const size_t& idx3, const size_t& idx4,
-                          const size_t& idx5, const size_t& idx6,
-                          const size_t& idx7,
-                          ::Kokkos::View<DataType, ViewParams...>* d_v,
-                          const ::std::string* /*d_name*/,
-                          const size_t& /*d_idx0*/, const size_t* /*d_idx1*/,
-                          const size_t* /*d_idx2*/, const size_t* /*d_idx3*/,
-                          const size_t* /*d_idx4*/, const size_t* /*d_idx5*/,
-                          const size_t* /*d_idx6*/, const size_t* /*d_idx7*/) {}
-
+template <class DataType, size_t N, class... ViewParams>
+void constructor_pullback(
+    const char (&name)[N], const size_t idx0, const size_t idx1,
+    const size_t idx2, const size_t idx3, const size_t idx4, const size_t idx5,
+    const size_t idx6, const size_t idx7,
+    ::Kokkos::View<DataType, ViewParams...>* d_this, char (*)[2] /*d_name*/,
+    unsigned long* /*d_idx0*/, size_t* /*d_idx1*/, size_t* /*d_idx2*/,
+    size_t* /*d_idx3*/, size_t* /*d_idx4*/, size_t* /*d_idx5*/,
+    size_t* /*d_idx5*/, size_t* /*d_idx6*/);
 /// View indexing
 template <typename View, typename Idx>
 inline clad::ValueAndPushforward<typename View::reference_type,
@@ -469,12 +464,12 @@ void resize_pushforward(
   ::Kokkos::resize(v, n0, n1, n2, n3, n4, n5, n6, n7);
   ::Kokkos::resize(d_v, n0, n1, n2, n3, n4, n5, n6, n7);
 }
-template <class I, class dI, class View>
+template <class I, class View>
 void resize_pushforward(
     const I& arg, View& v, const ::std::size_t n0, const ::std::size_t n1,
     const ::std::size_t n2, const ::std::size_t n3, const ::std::size_t n4,
     const ::std::size_t n5, const ::std::size_t n6, const ::std::size_t n7,
-    const dI& /*d_arg*/, View& d_v, const ::std::size_t /*d_n*/,
+    const I& /*d_arg*/, View& d_v, const ::std::size_t /*d_n*/,
     const ::std::size_t /*d_n*/, const ::std::size_t /*d_n*/,
     const ::std::size_t /*d_n*/, const ::std::size_t /*d_n*/,
     const ::std::size_t /*d_n*/, const ::std::size_t /*d_n*/,
@@ -507,7 +502,7 @@ void resize_reverse_forw(
   ::Kokkos::resize(arg, v, n0, n1, n2, n3, n4, n5, n6, n7);
   ::Kokkos::resize(arg, d_v, n0, n1, n2, n3, n4, n5, n6, n7);
 }
-template <class... Args> void resize_pullback(Args... /*args*/) {}
+template <class... Args> void resize_pullback(Args... /*args*/);
 
 /// Fence
 template <typename S> void fence_pushforward(const S& s, const S& /*d_s*/) {
@@ -1061,4 +1056,4 @@ void parallel_reduce_pushforward(const ::std::string& str, const Policy& policy,
 } // namespace Kokkos
 } // namespace clad::custom_derivatives
 
-#endif // CLAD_DIFFERENTIATOR_KOKKOSBUILTINS_H
\ No newline at end of file
+#endif // CLAD_DIFFERENTIATOR_KOKKOSBUILTINS_H
