@@ -27,6 +27,7 @@
 #include "Math/GenVector/RotationYfwd.h"
 
 #include <cmath>
+#include <TMath.h>
 
 namespace ROOT {
 namespace Math {
@@ -39,7 +40,7 @@ namespace Math {
 
       @ingroup GenVector
 
-      @sa Overview of the @ref GenVector "physics vector library"
+      @see GenVector
    */
 
 class RotationY {
@@ -72,9 +73,9 @@ public:
       Rectify makes sure the angle is in (-pi,pi]
    */
    void Rectify()  {
-      if ( std::fabs(fAngle) >= M_PI ) {
-         double x = fAngle / (2.0 * M_PI);
-         fAngle =  (2.0 * M_PI) * ( x + std::floor(.5-x) );
+      if (std::fabs(fAngle) >= TMath::Pi()) {
+         double x = fAngle / TMath::TwoPi();
+         fAngle = TMath::TwoPi() * (x + std::floor(.5 - x));
          fSin = std::sin(fAngle);
          fCos = std::cos(fAngle);
       }
@@ -195,8 +196,8 @@ public:
    */
    RotationY operator * (const RotationY & r) const {
       RotationY ans;
-      double x   = (fAngle + r.fAngle) / (2.0 * M_PI);
-      ans.fAngle = (2.0 * M_PI) * ( x + std::floor(.5-x) );
+      double x = (fAngle + r.fAngle) / TMath::TwoPi();
+      ans.fAngle = TMath::TwoPi() * (x + std::floor(.5 - x));
       ans.fSin   = fSin*r.fCos + fCos*r.fSin;
       ans.fCos   = fCos*r.fCos - fSin*r.fSin;
       return ans;
