@@ -43,7 +43,6 @@
 #undef R__USE_LIBCXX    /**/
 #define R__HAS_ATTRIBUTE_ALWAYS_INLINE /**/
 #define R__HAS_ATTRIBUTE_NOINLINE /**/
-#undef R__HAS_HARDWARE_INTERFERENCE_SIZE /**/
 #define R__USE_IMT   /**/
 #undef R__COMPLETE_MEM_TERMINATION /**/
 #undef R__HAS_CEFWEB  /**/
@@ -53,6 +52,8 @@
 #define R__HAS_ROOT7 /**/
 #undef R__LESS_INCLUDES /**/
 #define R__HAS_TBB /**/
+#define R__HARDWARE_INTERFERENCE_SIZE 64
+ /*Determined at CMake configure to be stable across all TUs*/
 
 #if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
 #ifndef VECCORE_ENABLE_VC
@@ -74,4 +75,6 @@
 
 #define R__HAS_URING /**/
 
+#define R__HAS_GEOM /**/
+
 #endif
