@@ -16,34 +16,39 @@
 #ifndef ROO_EXPONENTIAL
 #define ROO_EXPONENTIAL
 
-#include "RooAbsPdf.h"
-#include "RooRealProxy.h"
-
-class RooRealVar;
-class RooAbsReal;
+#include <RooAbsPdf.h>
+#include <RooRealProxy.h>
 
 class RooExponential : public RooAbsPdf {
 public:
-  RooExponential() {} ;
-  RooExponential(const char *name, const char *title,
-       RooAbsReal& _x, RooAbsReal& _c);
-  RooExponential(const RooExponential& other, const char* name=0);
-  virtual TObject* clone(const char* newname) const override { return new RooExponential(*this,newname); }
-  inline virtual ~RooExponential() { }
+   RooExponential() {}
+   RooExponential(const char *name, const char *title, RooAbsReal &variable, RooAbsReal &coefficient,
+                  bool negateCoefficient = false);
+   RooExponential(const RooExponential &other, const char *name = nullptr);
+   TObject *clone(const char *newname) const override { return new RooExponential(*this, newname); }
 
-  Int_t getAnalyticalIntegral(RooArgSet& allVars, RooArgSet& analVars, const char* rangeName=0) const override;
-  Double_t analyticalIntegral(Int_t code, const char* rangeName=0) const override;
+   Int_t getAnalyticalIntegral(RooArgSet &allVars, RooArgSet &analVars, const char *rangeName = nullptr) const override;
+   double analyticalIntegral(Int_t code, const char *rangeName = nullptr) const override;
+
+   /// Get the x variable.
+   RooAbsReal const &variable() const { return x.arg(); }
+
+   /// Get the coefficient "c".
+   RooAbsReal const &coefficient() const { return c.arg(); }
+
+   bool negateCoefficient() const { return _negateCoefficient; }
 
 protected:
-  RooRealProxy x;
-  RooRealProxy c;
+   RooRealProxy x;
+   RooRealProxy c;
+   bool _negateCoefficient = false;
+
+   double evaluate() const override;
+   void doEval(RooFit::EvalContext &) const override;
+   inline bool canComputeBatchWithCuda() const override { return true; }
 
-  double evaluate() const override;
-  void computeBatch(cudaStream_t*, double* output, size_t nEvents, RooFit::Detail::DataMap const&) const override;
-  inline bool canComputeBatchWithCuda() const override { return true; }
-  
 private:
-  ClassDefOverride(RooExponential,1) // Exponential PDF
+   ClassDefOverride(RooExponential, 2) // Exponential PDF
 };
 
 #endif
